[Cluster-devel] cluster/cman/daemon ais.c

pcaulfield at sourceware.org pcaulfield at sourceware.org
Tue Oct 31 17:27:46 UTC 2006


CVSROOT:	/cvs/cluster
Module name:	cluster
Changes by:	pcaulfield at sourceware.org	2006-10-31 17:27:45

Modified files:
	cman/daemon    : ais.c 

Log message:
	On Steven Dake's recommendation, also up the token_retransmit count to 20.
	and fix a couple of typos.

Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/cluster/cman/daemon/ais.c.diff?cvsroot=cluster&r1=1.43&r2=1.44

--- cluster/cman/daemon/ais.c	2006/10/31 09:28:12	1.43
+++ cluster/cman/daemon/ais.c	2006/10/31 17:27:45	1.44
@@ -470,7 +470,7 @@
 			       "totem", strlen("totem"),
 			       &object_handle) == 0)
 	{
-		void *value = NULL;
+		char *value;
 
 		objdb->object_key_create(object_handle, "version", strlen("version"),
 					 "2", 2);
@@ -482,12 +482,17 @@
 		objdb->object_key_create(object_handle, "vsftype", strlen("vsftype"),
 					 "none", strlen("none")+1);
 
 		/* Set the token timeout is 5 seconds, but don't overrride anything that
 		   might be in cluster.conf */
-		if (objdb->object_key_get(object_handle, "token", strlen("token"), &value, NULL) || value == NULL) {
+		if (objdb_get_string(objdb, object_handle, "token", &value)) {
 			global_objdb->object_key_create(object_handle, "token", strlen("token"),
 							"5000", strlen("5000")+1);
 		}
+		if (objdb_get_string(objdb, object_handle, "token_retransmits_before_loss_const", &value)) {
+			global_objdb->object_key_create(object_handle, "token_retransmits_before_loss_const",
+							strlen("token_retransmits_before_loss_const"),
+							"20", strlen("20")+1);
+		}
 
 		/* Set RRP mode appropriately */
 		if (num_interfaces > 1) {
@@ -509,7 +514,7 @@
 						 key_filename, strlen(key_filename)+1);
 		}
 		else /* Use the cluster name as key,
-		      * This isn't a good isolation strategey but it does make sure that
+		      * This isn't a good isolation strategy but it does make sure that
 		      * clusters on the same port/multicast by mistake don't actually interfere
 		      * and that we have some form of encryption going.
 		      */
@@ -536,7 +541,7 @@
 		char *logstr;
 
 		/* Default logging facility is "local4" unless overridden by the user */
-		if (!objdb_get_string(objdb, object_handle, "syslog_facility", &logstr)) {
+		if (objdb_get_string(objdb, object_handle, "syslog_facility", &logstr)) {
 			objdb->object_key_create(object_handle, "syslog_facility", strlen("syslog_facility"),
 						 "local4", strlen("local4")+1);
 		}
@@ -482,12 +482,17 @@
 					 "none", strlen("none")+1);
 
-		/* Set the token timeout is 5 seconds, but don't overrride anything that
+		/* Set the token timeout is 5 seconds - 20 losses, but don't overrride anything that
 		   might be in cluster.conf */




More information about the Cluster-devel mailing list